import type { AnchorHTMLAttributes, FC, MouseEventHandler } from 'react';
import { AnimateConfig } from './helpers';
export interface ScrollchorProps extends Omit<AnchorHTMLAttributes<HTMLAnchorElement>, 'href' | 'onClick'> {
    /**
     * The anchor (id) to which this link should scroll to, leading # will be stripped
     */
    to: string;
    /**
     * The element scrolling will be performed on when clicked, leading # will be stripped
     *
     * Defaults to scrolling both the `<html>` and `<body>` elements of the page
     */
    target?: string;
    /**
     * The smooth scrolling animation can be customized using this prop. Three pre-defined
     * easing functions are exported by the package: `easeOutQuad`, `swing`, `linear`.
     *
     * @example ```
     * { offset: 0, duration: 400, easing: easeOutQuad }
     * ```
     */
    animate?: Partial<AnimateConfig>;
    /**
     * Callback function triggered before scroll to #hash
     */
    beforeAnimate?: MouseEventHandler;
    /**
     * Callback function triggered after scroll to #hash
     */
    afterAnimate?: MouseEventHandler;
    /**
     * Enable/disable updating the browser history with scroll behaviours
     *
     * Default to `false`
     */
    disableHistory?: boolean;
}
export declare const Scrollchor: FC<ScrollchorProps>;
